.. Gym Xiangqi documentation master file, created by
   sphinx-quickstart on Mon Apr  5 19:32:40 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Gym Xiangqi's documentation!
=======================================

Gym Xiangqi is a reinforcement learning environment of the Xiangqi (Chinese Chess) game.
The project is built on top of a popular reinforcement learning framework called
`OpenAI Gym <https://gym.openai.com/>`_. Please check out this documentation page and our
`Github repository <https://github.com/tanliyon/gym-xiangqi>`_ for more information!


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   examples
   api
   gui

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
